[Bf-extensions-cvs] SVN commit: /data/svn/bf-extensions [4192] trunk/py/scripts/addons/rigify/ generate.py: Rigify: patch from Shinsuke Irie, updating name limits.

Nathan Vegdahl cessen at cessen.com
Tue Jan 22 19:41:16 CET 2013


Revision: 4192
          http://projects.blender.org/scm/viewvc.php?view=rev&root=bf-extensions&revision=4192
Author:   cessen
Date:     2013-01-22 18:41:16 +0000 (Tue, 22 Jan 2013)
Log Message:
-----------
Rigify: patch from Shinsuke Irie, updating name limits.

Blender increased object name length limit from 21 to 63 at some point,
and I hadn't update Rigify to reflect that.  This enables better reliability
with respect to widget shapes.

Modified Paths:
--------------
    trunk/py/scripts/addons/rigify/generate.py

Modified: trunk/py/scripts/addons/rigify/generate.py
===================================================================
--- trunk/py/scripts/addons/rigify/generate.py	2013-01-22 18:19:06 UTC (rev 4191)
+++ trunk/py/scripts/addons/rigify/generate.py	2013-01-22 18:41:16 UTC (rev 4192)
@@ -350,7 +350,7 @@
     # Assign shapes to bones
     # Object's with name WGT-<bone_name> get used as that bone's shape.
     for bone in bones:
-        wgt_name = (WGT_PREFIX + obj.data.bones[bone].name)[:21]  # Object names are limited to 21 characters... arg
+        wgt_name = (WGT_PREFIX + obj.data.bones[bone].name)[:63]  # Object names are limited to 63 characters... arg
         if wgt_name in context.scene.objects:
             # Weird temp thing because it won't let me index by object name
             for ob in context.scene.objects:



More information about the Bf-extensions-cvs mailing list